@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-import os
+from pathlib import Path
 
 from simmate.workflow_engine import ErrorHandler
 from simmate.calculators.vasp.inputs import Incar
@@ -16,17 +16,17 @@ class Edddav(ErrorHandler):
     filename_to_check = "vasp.out"
     possible_error_messages = ["EDWAV: internal error, the gradient is not orthogonal"]
 
-    def correct(self, directory: str) -> str:
+    def correct(self, directory: Path) -> str:
 
         # load the INCAR file to view the current settings
-        incar_filename = os.path.join(directory, "INCAR")
+        incar_filename = directory / "INCAR"
         incar = Incar.from_file(incar_filename)
 
         correction = ""
         # Delete the CHGCAR if this is a "from-scratch" calc
         current_icharg = incar.get("ICHARG", 0)
         if current_icharg < 10:
-            os.remove(os.path.join(dir, "CHGCAR"))
+            (directory / "CHGCAR").unlink()
             correction += "deleted CHGCAR and "
         incar["ALGO"] = "All"
         correction += "switched ALGO to Normal"
