@@ -1,7 +1,8 @@
 # -*- coding: utf-8 -*-
 
-from simmate.workflow_engine import ErrorHandler
+from pathlib import Path
 
+from simmate.workflow_engine import ErrorHandler
 from simmate.calculators.vasp.error_handlers import TetrahedronMesh, IncorrectShift
 
 
@@ -15,7 +16,7 @@ class Tetirr(ErrorHandler):
     filename_to_check = "vasp.out"
     possible_error_messages = ["Routine TETIRR needs special values"]
 
-    def correct(self, directory: str) -> str:
+    def correct(self, directory: Path) -> str:
 
         # apply the fixes uses these other error handlers
         fixes_1 = TetrahedronMesh().correct(directory)
