@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-import os
+from pathlib import Path
 
 from simmate.toolkit import Structure
 from simmate.workflow_engine import ErrorHandler
@@ -17,16 +17,16 @@ class TripleProduct(ErrorHandler):
     filename_to_check = "vasp.out"
     possible_error_messages = ["ERROR: the triple product of the basis vectors"]
 
-    def correct(self, directory: str) -> str:
+    def correct(self, directory: Path) -> str:
 
         # load the INCAR file to view the current settings
-        incar_filename = os.path.join(directory, "INCAR")
+        incar_filename = directory / "INCAR"
         incar = Incar.from_file(incar_filename)
 
         # load the structure and save it as a backup file
-        poscar_filename = os.path.join(directory, "POSCAR")
+        poscar_filename = directory / "POSCAR"
         structure = Structure.from_file(poscar_filename)
-        structure.to("POSCAR", poscar_filename + "_original")
+        structure.to("POSCAR", poscar_filename.with_stem("POSCAR_original"))
 
         # switch the b and c lattice vector of the structure
         structure.make_supercell([[1, 0, 0], [0, 0, 1], [0, 1, 0]])
