@@ -1,14 +1,16 @@
 # -*- coding: utf-8 -*-
 
 from .diffusion.all import (
-    Diffusion__Vasp__NebAllPaths,
-    Diffusion__Vasp__NebSinglePath,
-    Diffusion__Vasp__NebFromEndpoints,
-    Diffusion__Vasp__NebFromImages,
+    Diffusion__Vasp__NebAllPathsMit,
+    Diffusion__Vasp__NebSinglePathMit,
+    Diffusion__Vasp__NebFromEndpointsMit,
+    Diffusion__Vasp__NebFromImagesMit,
+    Diffusion__Vasp__NebFromImagesMvlCi,
 )
 
 from .electronic_structure.all import (
     ElectronicStructure__Vasp__MatprojFull,
+    ElectronicStructure__Vasp__MatprojHseFull,
 )
 
 from .population_analysis.all import (
@@ -19,15 +21,22 @@ from .population_analysis.all import (
 
 from .static_energy.all import (
     StaticEnergy__Vasp__Matproj,
+    StaticEnergy__Vasp__MatprojHse,
+    StaticEnergy__Vasp__MatprojScan,
     StaticEnergy__Vasp__Mit,
     StaticEnergy__Vasp__Quality04,
-    StaticEnergy__Vasp__NebEndpoint,
+    StaticEnergy__Vasp__MvlNebEndpoint,
 )
 
 from .relaxation.all import (
     Relaxation__Vasp__Matproj,
+    Relaxation__Vasp__MatprojHse,
+    Relaxation__Vasp__MatprojScan,
+    Relaxation__Vasp__MatprojMetal,
     Relaxation__Vasp__Mit,
-    Relaxation__Vasp__NebEndpoint,
+    Relaxation__Vasp__MvlGrainboundary,
+    Relaxation__Vasp__MvlSlab,
+    Relaxation__Vasp__MvlNebEndpoint,
     Relaxation__Vasp__Quality00,
     Relaxation__Vasp__Quality01,
     Relaxation__Vasp__Quality02,
@@ -36,6 +45,10 @@ from .relaxation.all import (
     Relaxation__Vasp__Staged,
 )
 
-from .customized import Customized__Vasp__UserConfig
+from .dynamics.all import (
+    Dynamics__Vasp__Mit,
+    Dynamics__Vasp__Matproj,
+    Dynamics__Vasp__MvlNpt,
+)
 
-from .dynamics import Dynamics__Vasp__Mit
+from .customized import Customized__Vasp__UserConfig
