@@ -1,8 +1,13 @@
 # -*- coding: utf-8 -*-
 
 from .matproj import Relaxation__Vasp__Matproj
+from .matproj_hse import Relaxation__Vasp__MatprojHse
+from .matproj_scan import Relaxation__Vasp__MatprojScan
+from .matproj_metal import Relaxation__Vasp__MatprojMetal
 from .mit import Relaxation__Vasp__Mit
-from .neb_endpoint import Relaxation__Vasp__NebEndpoint
+from .mvl_grainboundary import Relaxation__Vasp__MvlGrainboundary
+from .mvl_slab import Relaxation__Vasp__MvlSlab
+from .mvl_neb_endpoint import Relaxation__Vasp__MvlNebEndpoint
 from .quality00 import Relaxation__Vasp__Quality00
 from .quality01 import Relaxation__Vasp__Quality01
 from .quality02 import Relaxation__Vasp__Quality02
