@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 
 from typing import List
+import pathlib
 
 import click
 from click import Context
@@ -187,16 +188,7 @@ def show_config(workflow_name):
 
     click.echo("PRINTING WORKFLOW CONFIG...")
 
-    # Not all workflows have a single config because some are NestWorkflows,
-    # meaning they are made of multiple smaller workflows.
-    if workflow.s3task:
-        workflow.s3task.print_config()
-    else:
-        raise click.ClickException(
-            "This is not a S3Task-based workflow. It is likely a NestedWorkflow, "
-            "meaning it is made up of multiple smaller workflows. We have not "
-            "added a show-config feature for these yet. "
-        )
+    workflow.show_config()
 
 
 @workflows.command(
@@ -214,7 +206,7 @@ def setup_only(context, workflow_name):
     """
 
     click.echo("LOADING STRUCTURE AND WORKFLOW...")
-    from simmate.toolkit import Structure
+
     from simmate.workflows.utilities import get_workflow
 
     workflow = get_workflow(
@@ -233,16 +225,21 @@ def setup_only(context, workflow_name):
 
     directory = kwargs_cleaned.get("directory", None)
     if not directory:
-        directory = get_directory(f"{workflow.name_full}.SETUP-ONLY")
-        kwargs_cleaned["directory"] = directory
+        directory = f"{workflow.name_full}.SETUP-ONLY"
+
+    # ensure a path obj and that directory is created
+    kwargs_cleaned["directory"] = get_directory(directory)
 
     # Not all workflows have a single input because some are NestWorkflows,
     # meaning they are made of multiple smaller workflows.
-    if workflow.s3task:
-        workflow.s3task.setup(**kwargs_cleaned)
+    from simmate.workflow_engine import S3Workflow
+
+    if issubclass(workflow, S3Workflow):
+
+        workflow.setup(**kwargs_cleaned)
     else:
         raise click.ClickException(
-            "This is not a S3Task-based workflow. It is likely a NestedWorkflow, "
+            "This is not a S3-based workflow. It is likely a NestedWorkflow, "
             "meaning it is made up of multiple smaller workflows. We have not "
             "added a setup-only feature for these yet. "
         )
@@ -318,7 +315,7 @@ def run_cloud(context, workflow_name):
         allow_extra_args=True,
     )
 )
-@click.argument("filename", type=click.Path(exists=True))
+@click.argument("filename", type=click.Path(exists=True, path_type=pathlib.Path))
 def run_yaml(filename):
     """Runs a workflow where parameters are loaded from a yaml file."""
 
@@ -326,7 +323,7 @@ def run_yaml(filename):
 
     import yaml
 
-    with open(filename) as file:
+    with filename.open() as file:
         parameters = yaml.full_load(file)  # this is updated below
 
     from simmate.workflows.utilities import get_workflow
