@@ -8,20 +8,21 @@ See the `simmate.database.base_data_types` (which is the parent module of
 this one) for example usage.
 """
 
-import os
 import inspect
 import shutil
 import urllib
 import warnings
-
 import yaml
+import json
+from pathlib import Path
+from typing import List, Union
+import logging
 
 import pandas
 from django.db import models  # , transaction
 from django_pandas.io import read_frame
 from django.utils.timezone import datetime
 
-from typing import List
 
 # This line does NOTHING but rename a module. I have this because I want to use
 # "table_column.CharField(...)" instead of "models.CharField(...)" in my Models.
@@ -119,7 +120,7 @@ class SearchResults(models.QuerySet):
         # pymatgen objects as a list
         return [obj.to_toolkit() for obj in self]
 
-    def to_archive(self, filename: str = None):
+    def to_archive(self, filename: Union[str, Path] = None):
         """
         Writes a compressed zip file using the table's base_info attribute.
         Underneath, the file is written in a csv format.
@@ -157,10 +158,8 @@ class SearchResults(models.QuerySet):
             )
             filename = filename_base + ".zip"
 
-        # Turn the filename into the full path. We do this because we only
-        # want to
-        # filename = os.path.abspath(filename)
-        # os.path.dirname(filename)
+        # convert to path obj
+        filename = Path(filename)
 
         # grab the base_information, and if ID is not present, add it
         base_info = self.model.base_info
@@ -181,7 +180,7 @@ class SearchResults(models.QuerySet):
 
         # Write the data to a csv file
         # OPTIMIZE: is there a better format that pandas can write to?
-        csv_filename = filename.replace(".zip", ".csv")
+        csv_filename = filename.with_suffix(".csv")
         df.to_csv(csv_filename, index=False)
 
         # now convert the dump file to a compressed zip. In the complex, os
@@ -189,14 +188,27 @@ class SearchResults(models.QuerySet):
         # zip ending. We are also grabbing the directory that the csv is
         # located in
         shutil.make_archive(
-            base_name=filename.removesuffix(".zip"),
+            base_name=filename.with_suffix(""),  # removes .zip ending
             format="zip",
-            root_dir=os.path.dirname(os.path.abspath(csv_filename)),
-            base_dir=os.path.basename(csv_filename),
+            root_dir=csv_filename.absolute().parent,
+            base_dir=csv_filename.name,
         )
 
         # we can now delete the csv file
-        os.remove(csv_filename)
+        csv_filename.unlink()
+
+    def filter_by_tags(self, tags: list[str]):
+        """
+        A utility filter() method that
+        """
+
+        if tags:
+            new_query = self
+            for tag in tags:
+                new_query = new_query.filter(tags__icontains=tag)
+        else:
+            new_query = self.filter(tags=[])
+        return new_query
 
 
 # Copied this line from...
@@ -364,72 +376,6 @@ class DatabaseTable(models.Model):
         """
         return cls.__name__
 
-    @classmethod
-    def create_subclass(
-        cls,
-        name: str,
-        module: str,
-        app_label: str = None,
-        **new_columns,
-    ):
-        """
-        This method is useful for dynamically creating a subclass DatabaseTable
-        from some abstract class.
-
-        Let's take an example where we inherit from a Structure table. The two
-        ways we create a NewTable below are exactly the same:
-
-        ``` python
-        # Normal way to create a child class
-        NewTable(Structure):
-            new_field1 = table_column.FloatField()
-            new_field2 = table_column.FloatField()
-
-        # How this method makes the same child class
-        NewTable = Structure.create_subclass(
-            name="NewTable",
-            module=__name__, # required for serialization
-            new_field1 = table_column.FloatField()
-            new_field2 = table_column.FloatField()
-            # app_label --> typically not required bc the parent class sets this
-        )
-        ```
-
-        While this might seem silly, it helps us avoid a bunch of boilerplate
-        code when we need to redefine a bunch of relationships in every single
-        child class (and always in the same way). A great example of it's utility
-        is in `simmate.calculators.vasp.database.relaxation`.
-        """
-
-        # because we update values below, we make sure we are editting a
-        # copy of the dictionary
-        new_columns = new_columns.copy()
-
-        # BUG: I'm honestly not sure what this does, but it works...
-        # https://stackoverflow.com/questions/27112816/
-        # For a more robust way of setting the Meta class, see my code in
-        # simmate.website.workflows.utilities
-        new_columns.update(
-            {
-                "__module__": module,
-                "Meta": {"app_label": app_label} if app_label else {},
-            }
-        )
-        # TODO: make it so I don't have to specify the module, but it is automatically
-        # detected from where the class is created. This would remove boilerplate code.
-        # A good start to this is here:
-        #   https://stackoverflow.com/questions/59912684/
-        # sys._getframe(1).f_globals["__name__"]  <-- grabs where this function is called
-        # but doesn't work for multiple levels of inheritance. For example, this fails for
-        # the Relaxation subclasses because the create_subclasses method calls
-        # create_subclass -- therefore we'd need _getframe(3) instead of 1...
-
-        # Now we dynamically create a new class that inherits from this main
-        # one and also adds the new columns to it.
-        NewClass = type(name, (cls,), new_columns)
-
-        return NewClass
-
     @classmethod
     def from_toolkit(cls, as_dict: bool = False, **kwargs):
         """
@@ -594,7 +540,7 @@ class DatabaseTable(models.Model):
     @classmethod
     def load_archive(
         cls,
-        filename: str = None,
+        filename: Union[str, Path] = None,
         delete_on_completion: bool = False,
         confirm_override: bool = False,
         parallel: bool = False,
@@ -658,8 +604,8 @@ class DatabaseTable(models.Model):
             # grab the most recent date.
             matching_files = [
                 file
-                for file in os.listdir()
-                if file.startswith(cls.__name__) and file.endswith(".zip")
+                for file in Path.cwd().iterdir()
+                if file.name.startswith(cls.__name__) and file.suffix == ".zip"
             ]
             # make sure there is at least one file
             if not matching_files:
@@ -672,17 +618,17 @@ class DatabaseTable(models.Model):
 
         # Turn the filename into the full path -- which makes a number of
         # manipulations easier below.
-        filename = os.path.abspath(filename)
+        filename = Path(filename).absolute()
 
         # uncompress the zip file to the same directory that it is located in
         shutil.unpack_archive(
             filename,
-            extract_dir=os.path.dirname(filename),
+            extract_dir=filename.parent,
         )
 
         # We will now have a csv file of the same name, which we load into
         # a pandas dataframe
-        csv_filename = filename.replace(".zip", ".csv")
+        csv_filename = filename.with_suffix(".csv")  # was ".zip"
         df = pandas.read_csv(csv_filename)
 
         # BUG: NaN values throw errors when read into SQL databases, so we
@@ -697,6 +643,11 @@ class DatabaseTable(models.Model):
         # to enable parallelization, we define a function to load a single
         # entry (or row) of data. This allows us to submit the function to Dask.
         def load_single_entry(entry):
+            """
+            Quick utility function that load a single entry to the database.
+            We have this as a internal function in order to allow submitting
+            this function to Dask (for parallelization).
+            """
 
             # For all entries, convert the structure_string to a toolkit structure
             if "structure_string" in entry:
@@ -707,6 +658,16 @@ class DatabaseTable(models.Model):
             # converted to toolkit objects? This code may be better placed in
             # base_data_type methods (e.g. a `from_base_info` method for each)
 
+            # BUG: some columns don't properly convert to python objects, but
+            # it seems inconsistent when this is done... For now I just manually
+            # convert JSON columns
+            json_parsing_columns = ["site_forces", "lattice_stress"]
+            for column in json_parsing_columns:
+                if column in entry:
+                    if entry[column]:  # sometimes it has a value of None
+                        entry[column] = json.loads(entry[column])
+            # OPTIMIZE: consider applying this to the df column for faster loading
+
             entry_db = cls.from_toolkit(**entry)
             entry_db.save()
 
@@ -728,9 +689,9 @@ class DatabaseTable(models.Model):
             )
 
         # We can now delete the files. The zip file is only deleted if requested.
-        os.remove(csv_filename)
+        csv_filename.unlink()
         if delete_on_completion:
-            os.remove(filename)  # the zip archive
+            filename.unlink()  # the zip archive
 
     @classmethod
     def load_remote_archive(
@@ -790,23 +751,23 @@ class DatabaseTable(models.Model):
 
         # tell the user where the data comes from
         if cls._meta.app_label == "third_parties":
-            print(
-                "\nWARNING: this data is NOT from the Simmate team, so be sure "
+            logging.warn(
+                "this data is NOT from the Simmate team, so be sure "
                 "to visit the provider's website and to cite their work."
                 f" This data is from {cls.source} and the following paper "
-                f"should be cited: {cls.source_doi}\n"
+                f"should be cited: {cls.source_doi}"
             )
 
         # Predetermine the file name, which is just the ending of the URL
         archive_filename = remote_archive_link.split("/")[-1]
 
         # Download the archive zip file from the URL to the current working dir
-        print("Downloading archive file...")
+        logging.info("Downloading archive file...")
         urllib.request.urlretrieve(remote_archive_link, archive_filename)
-        print("Done.\n")
+        logging.info("Done.")
 
         # now that the archive is downloaded, we can load it into our db
-        print("Loading data into Simmate database...")
+        logging.info("Loading data into Simmate database...")
         cls.load_archive(
             archive_filename,
             delete_on_completion=True,
@@ -814,7 +775,7 @@ class DatabaseTable(models.Model):
             parallel=parallel,
             confirm_sqlite_parallel=True,  # we already confirmed this above
         )
-        print("Done.\n")
+        logging.info("Done.")
 
     @classmethod
     def get_column_names(cls) -> List[str]:
