@@ -4,7 +4,7 @@
 WARNING: This module is experimental and subject to change.
 """
 
-import os
+from pathlib import Path
 
 from pymatgen.core.sites import PeriodicSite
 from pymatgen.symmetry.analyzer import SpacegroupAnalyzer
@@ -21,7 +21,6 @@ from simmate.database.base_data_types import (
 # TODO: consider making a NestedCalculation
 class DiffusionAnalysis(Structure):
     class Meta:
-        abstract = True
         app_label = "workflows"
 
     migrating_specie = table_column.CharField(max_length=4, blank=True, null=True)
@@ -88,7 +87,7 @@ class DiffusionAnalysis(Structure):
         return structure_dict if as_dict else cls(**structure_dict)
 
     @classmethod
-    def from_directory(cls, directory: str, **kwargs):
+    def from_directory(cls, directory: Path, **kwargs):
         """
         Creates a new database entry from a directory that holds diffusion analysis
         results. For now, this assumes the directory holds vasp output files.
@@ -106,11 +105,7 @@ class DiffusionAnalysis(Structure):
         # messy for users)
         # For now, I only grab the structure from the static-energy and store
         # it in the DiffusionAnalysis table.
-        bulk_filename = os.path.join(
-            directory,
-            "static-energy.vasp.matproj",
-            "POSCAR",
-        )
+        bulk_filename = directory / "static-energy.vasp.matproj" / "POSCAR"
         bulk_structure = ToolkitStructure.from_file(bulk_filename)
 
         # Save a diffusion analysis object so we can connect all other data
@@ -126,10 +121,9 @@ class DiffusionAnalysis(Structure):
         # also cifs present that match this naming convention.
         # We ignore the number when saving to avoid overwriting data.
         migration_directories = [
-            os.path.join(directory, f)
-            for f in os.listdir(directory)
-            if os.path.isdir(os.path.join(directory, f))
-            and f.startswith("migration_hop_")
+            f.absolute()
+            for f in directory.iterdir()
+            if f.absolute().is_dir() and f.startswith("migration_hop_")
         ]
 
         # now save each migration hop present
@@ -141,85 +135,11 @@ class DiffusionAnalysis(Structure):
 
         return analysis_db
 
-    @classmethod
-    def create_subclasses(
-        cls,
-        name: str,
-        module: str,
-        **extra_columns,
-    ):
-        """
-        Dynamically creates a subclass of Relaxation as well as a separate IonicStep
-        table for it. These tables are linked together.
-
-        Example use:
-
-        ``` python
-        from simmate.database.base_data_types import Relaxation
-
-        # note the odd formatting here is just because we are parsing three
-        # outputs from this method to three variables.
-        (
-            ExampleDiffusionAnalysis,
-            ExampleMigrationHop,
-            ExampleMigrationImage,
-        ) = DiffusionAnalysis.create_subclasses(
-            "Example",
-            module=__name__,
-        )
-        ```
-
-        #### Parameters
-
-        - `name` :
-            The prefix name of the subclasses that are output. "Relaxation" and
-            "IonicStep" will be attached to the end of this prefix.
-
-        - `module` :
-            name of the module this subclass should be associated with. Typically,
-            you should pass __name__ to this.
-
-        - `**extra_columns` :
-            Additional columns to add to the table. The keyword will be the
-            column name and the value should match django options
-            (e.g. table_column.FloatField())
-
-        #### Returns
-
-        - `NewDiffusionAnalysisClass` :
-            A subclass of DiffusionAnalysis.
-        - `NewMigrationHopClass`:
-            A subclass of MigrationHop.
-        - `NewMigrationHopClass`:
-            A subclass of MigrationHop.
-        """
-
-        # For convience, we add columns that point to the start and end structures
-        NewDiffusionAnalysisClass = cls.create_subclass(
-            f"{name}DiffusionAnalysis",
-            module=module,
-            **extra_columns,
-        )
-
-        (
-            NewMigrationHopClass,
-            NewMigrationImageClass,
-        ) = MigrationHop.create_subclasses_from_diffusion_analysis(
-            name,
-            NewDiffusionAnalysisClass,
-            module=module,
-            **extra_columns,
-        )
-
-        # we now have a new child class and avoided writing some boilerplate code!
-        return NewDiffusionAnalysisClass, NewMigrationHopClass, NewMigrationImageClass
-
 
 # TODO: consider making a Calculation bc this is what the corrections/directory
 # information should be attached to.
 class MigrationHop(DatabaseTable):
     class Meta:
-        abstract = True
         app_label = "workflows"
 
     base_info = [
@@ -299,11 +219,11 @@ class MigrationHop(DatabaseTable):
     """ Relationships """
     # Each MigrationHop corresponds to the full analysis of one Structure, which
     # can have many MigrationHop(s)
-    # diffusion_analysis = table_column.ForeignKey(
-    #     # DiffusionAnalysis,
-    #     on_delete=table_column.PROTECT,
-    #     related_name="migration_hops",
-    # )
+    diffusion_analysis = table_column.ForeignKey(
+        DiffusionAnalysis,
+        on_delete=table_column.CASCADE,
+        related_name="migration_hops",
+    )
 
     # TODO:
     # image_start --> OneToOneField for specific MigrationHop
@@ -380,7 +300,7 @@ class MigrationHop(DatabaseTable):
     #######
 
     @classmethod
-    def from_directory(cls, directory: str, **kwargs):
+    def from_directory(cls, directory: Path, **kwargs):
         # I assume the directory is from a vasp calculation, but I need to update
         # this when I begin adding new calculators.
 
@@ -467,67 +387,9 @@ class MigrationHop(DatabaseTable):
 
         return hop_db
 
-    @classmethod
-    def create_subclasses_from_diffusion_analysis(
-        cls,
-        name: str,
-        diffusion_analysis: DiffusionAnalysis,
-        module: str,
-        **extra_columns,
-    ):
-        """
-        Dynamically creates subclass of MigrationHop and MigrationImage, then
-        links them to the DiffusionAnalysis table.
-
-        This method should NOT be called directly because it is instead used by
-        `DiffusionAnalysis.create_subclasses`.
-
-        #### Parameters
-
-        - `name` :
-            Name of the subclass that is output.
-        - `diffusion_analysis` :
-            DiffusionAnalysis table that these subclasses should be associated with.
-        - `module` :
-            name of the module this subclass should be associated with. Typically,
-            you should pass __name__ to this.
-        - `**extra_columns` :
-            Additional columns to add to the table. The keyword will be the
-            column name and the value should match django options
-            (e.g. table_column.FloatField())
-
-        #### Returns
-
-        - `NewMigrationHopClass`:
-            A subclass of MigrationHop.
-        - `NewMigrationHopClass`:
-            A subclass of MigrationHop.
-        """
-
-        NewMigrationHopClass = cls.create_subclass(
-            f"{name}MigrationHop",
-            diffusion_analysis=table_column.ForeignKey(
-                diffusion_analysis,
-                on_delete=table_column.CASCADE,
-                related_name="migration_hops",
-            ),
-            module=module,
-            **extra_columns,
-        )
-
-        NewMigrationImageClass = MigrationImage.create_subclass_from_migration_hop(
-            name,
-            NewMigrationHopClass,
-            module=module,
-            **extra_columns,
-        )
-
-        return NewMigrationHopClass, NewMigrationImageClass
-
 
 class MigrationImage(Structure):
     class Meta:
-        abstract = True
         app_label = "workflows"
 
     base_info = [
@@ -570,51 +432,8 @@ class MigrationImage(Structure):
     # deletes the source column from our Structure mix-in.
     source = None
 
-    @classmethod
-    def create_subclass_from_migration_hop(
-        cls,
-        name: str,
-        migration_hop: MigrationHop,
-        module: str,
-        **extra_columns,
-    ):
-        """
-        Dynamically creates subclass of MigrationImage, then links it to the
-        MigrationHop table.
-
-        This method should NOT be called directly because it is instead used by
-        `DiffusionAnalysis.create_subclasses`.
-
-        #### Parameters
-
-        - `name` :
-            Name of the subclass that is output.
-        - `migration_hop` :
-            MigrationHop table that these images should be associated with.
-        - `module` :
-            name of the module this subclass should be associated with. Typically,
-            you should pass __name__ to this.
-        - `**extra_columns` :
-            Additional columns to add to the table. The keyword will be the
-            column name and the value should match django options
-            (e.g. table_column.FloatField())
-
-        #### Returns
-
-        - `NewClass` :
-            A subclass of MigrationImage.
-
-        """
-
-        NewClass = cls.create_subclass(
-            f"{name}MigrationImage",
-            migration_hop=table_column.ForeignKey(
-                migration_hop,
-                on_delete=table_column.CASCADE,
-                related_name="migration_images",
-            ),
-            module=module,
-            **extra_columns,
-        )
-
-        return NewClass
+    migration_hop = table_column.ForeignKey(
+        MigrationHop,
+        on_delete=table_column.CASCADE,
+        related_name="migration_images",
+    )
