@@ -7,26 +7,30 @@ from pandas import DataFrame
 # from pymatgen.io.vasp.outputs import Vasprun
 
 from simmate.toolkit import Structure
-from simmate.website.test_app.models import TestRelaxation, TestIonicStep
+from simmate.database.base_data_types import Relaxation, IonicStep
 
 
 @pytest.mark.django_db
-def test_static_energy_table(structure):
+def test_relaxation_table(structure):
 
     # test writing columns
-    TestRelaxation.show_columns()
-    TestIonicStep.show_columns()
+    Relaxation.show_columns()
+    IonicStep.show_columns()
 
     # test writing to database
-    structure_db = TestRelaxation.from_prefect_id(
-        prefect_flow_run_id="example-id-123",
+    structure_db = Relaxation.from_run_context(
+        run_id="example-id-123",
+        workflow_name="example.test.workflow",
         structure=structure,
     )
     structure_db.save()
 
     # try grabbing the calculation again and make sure it loaded from the
     # database rather than creating a new entry
-    structure_db2 = TestRelaxation.from_prefect_id(prefect_flow_run_id="example-id-123")
+    structure_db2 = Relaxation.from_run_context(
+        run_id="example-id-123",
+        workflow_name="example.test.workflow",
+    )
     assert structure_db.id == structure_db2.id
 
     # test converting back to toolkit and ensuring the structure is the
@@ -35,8 +39,8 @@ def test_static_energy_table(structure):
     assert structure == structure_new
 
     # test converting search results to dataframe and to toolkit
-    df = TestRelaxation.objects.to_dataframe()
+    df = Relaxation.objects.to_dataframe()
     assert isinstance(df, DataFrame)
-    structures = TestRelaxation.objects.to_toolkit()
+    structures = Relaxation.objects.to_toolkit()
     assert isinstance(structures, list)
     assert isinstance(structures[0], Structure)
