@@ -1,13 +1,18 @@
 # -*- coding: utf-8 -*-
 
 from tqdm import tqdm
+import logging
 
 from simmate.toolkit import Structure as ToolkitStructure
 from simmate.database.base_data_types import DatabaseTable, table_column
 from simmate.utilities import get_chemical_subsystems
 
-from pymatgen.analysis.phase_diagram import PDEntry
-from pymatgen.analysis.phase_diagram import PhaseDiagram
+# BUG: This prints a tqdm error so we silence it here.
+import warnings
+
+with warnings.catch_warnings(record=True):
+    from pymatgen.analysis.phase_diagram import PDEntry
+    from pymatgen.analysis.phase_diagram import PhaseDiagram
 
 
 class Thermodynamics(DatabaseTable):
@@ -175,7 +180,7 @@ class Thermodynamics(DatabaseTable):
             try:
                 cls.update_chemical_system_stabilities(chemical_system)
             except ValueError as exception:
-                print(f"Failed for {chemical_system} with error: {exception}")
+                logging.warn(f"Failed for {chemical_system} with error: {exception}")
 
         # BUG: can't use parallel=True as an input
         # Because different systems may need to update a single one at the same
