@@ -1,7 +1,8 @@
 # -*- coding: utf-8 -*-
 
-import os
 import shutil
+from pathlib import Path
+import logging
 
 from django.apps import apps
 from django.core.management import call_command
@@ -34,8 +35,8 @@ def reset_database(apps_to_migrate=APPS_TO_MIGRATE, use_prebuilt=False):
     # Make sure the backend is using SQLite3 as this is the only allowed format
     using_sqlite = DATABASES["default"]["ENGINE"] == "django.db.backends.sqlite3"
     if not using_sqlite:
-        print(
-            "WARNING: reseting your database does not clear your database tables "
+        logging.warn(
+            "reseting your database does not clear your database tables "
             "for non-sqlite3 backends. Make sure you only use this function when "
             "initially building your database and not after."
         )
@@ -44,8 +45,8 @@ def reset_database(apps_to_migrate=APPS_TO_MIGRATE, use_prebuilt=False):
     db_filename = DATABASES["default"]["NAME"]
 
     # delete the sqlite3 database file if it exists
-    if os.path.exists(db_filename):
-        os.remove(db_filename)
+    if db_filename.exists():
+        db_filename.unlink()
 
     # go through each app directory and delete all folders named 'migrations'
     for app_name, app_config in apps.app_configs.items():
@@ -54,8 +55,8 @@ def reset_database(apps_to_migrate=APPS_TO_MIGRATE, use_prebuilt=False):
         if app_config.label not in apps_to_migrate:
             continue
 
-        migration_dir = os.path.join(app_config.path, "migrations")
-        if os.path.exists(migration_dir):
+        migration_dir = Path(app_config.path) / "migrations"
+        if migration_dir.exists():
             shutil.rmtree(migration_dir)
             continue
 
