@@ -7,7 +7,7 @@ It is a very basic extension PyMatGen's core Structure class, as it only adds
 a few extra methods and does not change any other usage.
 """
 
-import os
+from pathlib import Path
 
 from pymatgen.core import Structure as PymatgenStructure
 
@@ -97,18 +97,22 @@ class Structure(PymatgenStructure):
 
         # if the value is a str and it relates to a filepath, then we load the
         # structure from a file.
-        elif isinstance(structure, str) and os.path.exists(structure):
+        elif isinstance(structure, str) and Path(structure).exists():
             structure_cleaned = cls.from_file(structure)
 
         # Otherwise an incorrect format was given
         else:
-            raise Exception(
-                "Unknown format provided for structure input. "
-                f"{type(structure)} was provided. If you are trying "
-                "to provide a filepath (str), make sure you don't have "
-                "any typos and that the path is relative to the working "
-                "directory."
-            )
+            if isinstance(structure, str):
+                raise FileNotFoundError(
+                    "Are you trying to provide a filename as your input structure? "
+                    "If so, make sure you have the proper working directory set. "
+                    f"We were unable to find '{structure}' in '{Path.cwd()}'"
+                )
+            else:
+                raise Exception(
+                    "Unknown format provided for structure input. "
+                    f"{type(structure)} was provided."
+                )
 
         # add this attribute to help with error checking in other methods
         structure_cleaned.is_from_past_calc = is_from_past_calc
