@@ -2,6 +2,7 @@
 
 import numpy
 from tqdm import tqdm
+import logging
 
 from django.utils import timezone
 
@@ -17,6 +18,11 @@ from matminer.featurizers.structure.sites import (
     SiteStatsFingerprint,
 )  # PartialsSiteStatsFingerprint
 
+logging.warn(
+    "PartialsSiteStatsFingerprint current acts as a SiteStatsFingerprint. "
+    "We are waiting on a new MatMiner release to fix this issue."
+)
+
 
 class PartialCrystalNNFingerprint:
     def __init__(
@@ -141,7 +147,7 @@ class PartialCrystalNNFingerprint:
         if not new_structures:
             return
 
-        print(
+        logging.info(
             f"Found {len(new_structures)} new structures for the fingerprint database."
         )
 
