@@ -3,6 +3,8 @@
 import os
 import sys
 import requests
+from pathlib import Path
+import logging
 
 import simmate
 
@@ -50,12 +52,12 @@ def get_doc_from_readme(file: str) -> str:
     it's slower in production (bc of opening/closing files).
     """
 
-    # We assume the file is in the same directory and named "README.rst"
-    file_directory = os.path.dirname(os.path.abspath(file))
-    with open(
-        os.path.join(file_directory, "README.md"),
-        encoding="utf-8",
-    ) as doc_file:
+    # convert to path obj
+    file = Path(file)
+
+    # We assume the file is in the same directory and named "README.md"
+    readme = file.absolute().parent / "README.md"
+    with readme.open(encoding="utf-8") as doc_file:
         doc = doc_file.read()
     return doc
 
@@ -83,14 +85,10 @@ def check_if_using_latest_version(current_version=simmate.__version__):
     latest_version = get_latest_version()
 
     if current_version != latest_version:
-        print(
-            "WARNING: There is a new version of Simmate available. \n"
+        logging.warn(
+            "There is a new version of Simmate available. "
             f"You are currently using v{current_version} while v{latest_version} "
-            "is the latest. To update, you should first check what has been "
-            "changed at https://github.com/jacksund/simmate/blob/main/CHANGELOG.md. "
-            "If you would like to use these changes, you can run the follwing "
-            "command in the terminal (with your desired conda environment "
-            "active): `conda update --all`"
+            "is the latest."
         )
 
 
