@@ -8,12 +8,12 @@ __doc__ = get_doc_from_readme(__file__)
 # django in the code below this. These two imports don't depend on the database
 # module, so it may be worth isolating them for faster imports.
 from .error_handler import ErrorHandler
-from .supervised_staged_shell_task import S3Task
-from .worker import Worker
 
 # All imports below this point depend on the simmate.database module and therefore
 # need a database connection. This line sets up the database connection so
 # that models can be imported.
 from simmate.database import connect
 
-from .workflow import Workflow, task
+from .workflow import Workflow
+from .s3_workflow import S3Workflow
+from .execution import SimmateWorker as Worker
