@@ -1,21 +1,13 @@
 # -*- coding: utf-8 -*-
 
 import time
-
-# import pickle
 import cloudpickle  # needed to serialize Prefect workflow runs and tasks
+import logging
 
 from django.db import transaction
 
 from simmate.workflow_engine.execution.database import WorkItem
 
-# In the future, I might want this worker to be a local dask cluster that has
-# two threads going. One thread will update the queue database with a "heartbeat" to
-# let it know that it is still working on tasks. The other thread will run the
-# given workitems in serial. I could even allow for more threads so that this
-# worker can run multiple workitems at once and in parallel. I'm not sure if
-# asyncio would play into this though.
-
 # This string is just something fancy to display in the console when a worker
 # starts up.
 # This uses "Small Slant" from https://patorjk.com/software/taag/
@@ -29,16 +21,29 @@ HEADER_ART = r"""
 
 
 class SimmateWorker:
+
+    # Ideally, this worker would involve multiple threads threads going. One
+    # thread would update the queue database with a "heartbeat" to let it know
+    # that it is still working on tasks. The other thread will run the given
+    # workitems in serial. I could even allow for more threads so that this
+    # worker can run multiple workitems at once and in parallel.
+    # However, if this level of implementation is needed, we should instead
+    # switch to using Prefect, which has it built in.
+
     def __init__(
         self,
         # limit of tasks and lifetime of the worker
-        nitems_max=None,
-        timeout=None,
+        nitems_max: int = None,
+        timeout: float = None,
         # wait_on_timeout=False, # TODO
         # settings on what to do when the queue is empty
-        close_on_empty_queue=False,
-        waittime_on_empty_queue=60,
+        close_on_empty_queue: bool = False,
+        waittime_on_empty_queue: float = 1,
+        tags: list[str] = ["simmate"],  # should default be empty...?
     ):
+        # the tags to query tasks for. If no tags were given, the worker will
+        # query for tasks that have NO tags
+        self.tags = tags
 
         # the maximum number of workitems to run before closing down
         # if no limit was set, we can go to infinity!
@@ -64,6 +69,9 @@ class SimmateWorker:
         # print the header in the console to let the user know the worker started
         print(HEADER_ART)
 
+        # loggin helpful info
+        logging.info(f"Starting worker with tags {list(self.tags)}")
+
         # establish starting point for the worker
         time_start = time.time()
         ntasks_finished = 0
@@ -78,13 +86,18 @@ class SimmateWorker:
             # if we've hit the limit.
             if (time.time() - time_start) > self.timeout:
                 # TODO - check wait_on_timeout if running in parallel.
-                print("The time-limit for this worker has been hit.")
+                logging.info(
+                    "The time-limit for this worker has been hit. Shutting down."
+                )
                 return
 
             # check the number of jobs completed so far, and exit if we hit
             # the limit
             if ntasks_finished >= self.nitems_max:
-                print("Maxium number of WorkItems hit for this worker.")
+                logging.info(
+                    f"Maximum number of WorkItems reached ({self.nitems_max}). "
+                    "Shutting down."
+                )
                 return
 
             # check the length of the queue and while it is empty, we want to
@@ -100,14 +113,19 @@ class SimmateWorker:
                     # after we just waited, let's check the queue size again
                     if self.queue_size() == 0:
                         # if it's still empty, we should close the worker
-                        print("The queue is empty so the worker has been closed.")
+                        logging.info("The task queue is empty. Shutting down.")
                         return
 
             # If we've made it this far, we're ready to grab a new WorkItem
             # and run it!
             # Query for PENDING WorkItems, lock it for editting, and update
-            # the status to RUNNING
-            workitem = WorkItem.objects.select_for_update().filter(status="P").first()
+            # the status to RUNNING. And grab the first result
+            workitem = (
+                WorkItem.objects.select_for_update()
+                .filter(status="P")
+                .filter_by_tags(self.tags)
+                .first()
+            )
 
             # our lock exists only within this transation
             with transaction.atomic():
@@ -118,7 +136,7 @@ class SimmateWorker:
                 workitem.save()
 
             # Print out the job ID that is being ran for the user to see
-            print(f"Running WorkItem with id {workitem.id}.")
+            logging.info(f"Running WorkItem with id {workitem.id}")
 
             # now let's unpickle the WorkItem components
             fxn = cloudpickle.loads(workitem.fxn)
@@ -155,7 +173,7 @@ class SimmateWorker:
             ntasks_finished += 1
 
             # Print out the job ID that was just finished for the user to see.
-            print("Completed WorkItem.")
+            logging.info("Completed WorkItem")
 
     def queue_size(self):
         """
@@ -165,5 +183,16 @@ class SimmateWorker:
         # !!! Should I include RUNNING in the count? If so I do that with...
         #   from django.db.models import Q
         #   ...filter(Q(status="P") | Q(status="R"))
-        queue_size = WorkItem.objects.filter(status="P").count()
+        queue_size = (
+            WorkItem.objects.filter(status="P").filter_by_tags(self.tags).count()
+        )
         return queue_size
+
+    @classmethod
+    def run_singleflow_worker(cls):
+        worker = cls(
+            nitems_max=1,
+            close_on_empty_queue=True,
+            tags=["simmate"],
+        )
+        worker.start()
