@@ -5,8 +5,8 @@ Workflows for analyzing ionic diffusion with a material
 """
 
 from simmate.calculators.vasp.workflows.diffusion.all import (
-    Diffusion__Vasp__NebAllPaths,
-    Diffusion__Vasp__NebSinglePath,
-    Diffusion__Vasp__NebFromEndpoints,
-    Diffusion__Vasp__NebFromImages,
+    Diffusion__Vasp__NebAllPathsMit,
+    Diffusion__Vasp__NebSinglePathMit,
+    Diffusion__Vasp__NebFromEndpointsMit,
+    Diffusion__Vasp__NebFromImagesMit,
 )
