@@ -30,18 +30,26 @@ def test_list_of_all_workflows():
 
     assert get_list_of_all_workflows() == [
         "customized.vasp.user-config",
-        "diffusion.vasp.neb-all-paths",
-        "diffusion.vasp.neb-from-endpoints",
-        "diffusion.vasp.neb-from-images",
-        "diffusion.vasp.neb-single-path",
+        "diffusion.vasp.neb-all-paths-mit",
+        "diffusion.vasp.neb-from-endpoints-mit",
+        "diffusion.vasp.neb-from-images-mit",
+        "diffusion.vasp.neb-single-path-mit",
+        "dynamics.vasp.matproj",
         "dynamics.vasp.mit",
+        "dynamics.vasp.mvl-npt",
         "electronic-structure.vasp.matproj-full",
+        "electronic-structure.vasp.matproj-hse-full",
         "population-analysis.vasp.badelf-matproj",
         "population-analysis.vasp.bader-matproj",
         "population-analysis.vasp.elf-matproj",
         "relaxation.vasp.matproj",
+        "relaxation.vasp.matproj-hse",
+        "relaxation.vasp.matproj-metal",
+        "relaxation.vasp.matproj-scan",
         "relaxation.vasp.mit",
-        "relaxation.vasp.neb-endpoint",
+        "relaxation.vasp.mvl-grainboundary",
+        "relaxation.vasp.mvl-neb-endpoint",
+        "relaxation.vasp.mvl-slab",
         "relaxation.vasp.quality00",
         "relaxation.vasp.quality01",
         "relaxation.vasp.quality02",
@@ -50,8 +58,10 @@ def test_list_of_all_workflows():
         "relaxation.vasp.staged",
         "restart.simmate.automatic",
         "static-energy.vasp.matproj",
+        "static-energy.vasp.matproj-hse",
+        "static-energy.vasp.matproj-scan",
         "static-energy.vasp.mit",
-        "static-energy.vasp.neb-endpoint",
+        "static-energy.vasp.mvl-neb-endpoint",
         "static-energy.vasp.quality04",
     ]
 
@@ -60,8 +70,10 @@ def test_list_of_workflows_by_type():
 
     assert get_list_of_workflows_by_type("static-energy") == [
         "static-energy.vasp.matproj",
+        "static-energy.vasp.matproj-hse",
+        "static-energy.vasp.matproj-scan",
         "static-energy.vasp.mit",
-        "static-energy.vasp.neb-endpoint",
+        "static-energy.vasp.mvl-neb-endpoint",
         "static-energy.vasp.quality04",
     ]
 
@@ -81,6 +93,7 @@ def test_get_workflow():
 def test_get_unique_paramters():
     assert get_unique_parameters() == [
         "command",
+        "compress_output",
         "copy_previous_directory",
         "diffusion_analysis_id",
         "directory",
@@ -88,10 +101,14 @@ def test_get_unique_paramters():
         "directory_old",
         "input_parameters",
         "is_restart",
+        "max_atoms",
         "migrating_specie",
         "migration_hop",
         "migration_hop_id",
         "migration_images",
+        "min_atoms",
+        "min_length",
+        "nimages",
         "nsteps",
         "pre_sanitize_structure",
         "pre_standardize_structure",
@@ -108,12 +125,12 @@ def test_get_unique_paramters():
 
 
 @pytest.mark.django_db
-def test_load_results_from_directories(tmpdir):
+def test_load_results_from_directories(tmp_path):
 
     copy_test_files(
-        tmpdir,
+        tmp_path,
         test_directory=__file__,
         test_folder="",  # copy over the entire folder
     )
 
-    load_results_from_directories(base_directory=tmpdir)
+    load_results_from_directories(base_directory=tmp_path)
