@@ -6,12 +6,13 @@ functions for grabbing all available workflows as well as dynamically loading
 a workflow using its name.
 """
 
-import os
 import yaml
 import shutil
 import pkgutil
-from typing import List
+from typing import List, Union
 from importlib import import_module
+from pathlib import Path
+import logging
 
 from simmate import workflows
 from simmate.utilities import get_directory, make_archive
@@ -191,9 +192,7 @@ def get_workflow(
     return workflow
 
 
-def load_results_from_directories(
-    base_directory: str = ".",
-):
+def load_results_from_directories(base_directory: Union[str, Path] = "."):
     """
     Goes through a given directory and finds all "simmate-task-" folders and zip
     archives present. The simmate_metadata.yaml file is used in each of these
@@ -215,9 +214,7 @@ def load_results_from_directories(
     #   2. start with "simmate-task-"
     #   3. haven't been modified for at least time_cutoff
     foldernames = [
-        os.path.join(directory, f)
-        for f in os.listdir(directory)
-        if "simmate-task-" in os.path.basename(f)
+        directory / f for f in directory.iterdir() if "simmate-task-" in f.name
     ]
 
     # Now go through this list and archive the folders that met the criteria
@@ -226,7 +223,7 @@ def load_results_from_directories(
 
         # Print message for monitoring progress.
         # TODO: consider switching to tqdm
-        print(f"Loading data from... \n\t{foldername}")
+        logging.info(f"Loading data from {foldername}")
 
         # There may be many folders that contain failed or incomplete data.
         # We don't want those to prevent others from being loaded so we put
@@ -234,7 +231,7 @@ def load_results_from_directories(
         try:
 
             # If we have a zip file, we need to unpack it before we can read results
-            if not os.path.isdir(foldername):
+            if not foldername.is_dir():
                 shutil.unpack_archive(
                     filename=foldername,
                     extract_dir=directory,
@@ -243,8 +240,8 @@ def load_results_from_directories(
                 foldername = foldername.removesuffix(".zip")
 
             # Grab the metadata file which tells us key information
-            filename = os.path.join(foldername, "simmate_metadata.yaml")
-            with open(filename) as file:
+            filename = foldername / "simmate_metadata.yaml"
+            with filename.open() as file:
                 metadata = yaml.full_load(file)
 
             # see which workflow was used -- which also tells us the database table
@@ -256,7 +253,7 @@ def load_results_from_directories(
 
             # use the metadata to update the other fields
             results_db.source = metadata["source"]
-            results_db.prefect_flow_run_id = metadata["prefect_flow_run_id"]
+            results_db.run_id = metadata["run_id"]
 
             # note the directory might have been moved from when this was originally
             # ran vs where it is now. Therefore, we update the folder location here.
@@ -266,10 +263,10 @@ def load_results_from_directories(
             results_db.save()
             make_archive(foldername)
 
-            print("\tSuccessful.")
+            logging.info("Successfully loaded into database.")
 
         except:
-            print("\tFailed.")
+            logging.warn("Failed to load into database")
 
 
 def get_unique_parameters() -> List[str]:
